# frozen_string_literal: true
# GetYourRep module functions.
module GetYourRep
  module_function

  include GetYourRep::Errors

  # Get all reps using Google for national legislators,
  # and OpenStates for state reps.
  def all_reps(address)
    @delegation = Google.all_reps(address, congress_only: true)
    open_states = OpenStates.all_reps(address)
    @delegation.merge(open_states)
  end

  # Check if an address value is a zip code or a full address.
  def address_is_a_zip?(address)
    address = convert_int_address_to_string(address)
    if address.is_a?(String)
      address =~ /^\d{5}(-\d{4})?$/ ? true : false
    else
      address_type_error
    end
  end

  # Convert a zip code to a street address using Geocoder to convert zip to coordinates
  # and coordinates to an address.
  def convert_zip_to_address(address)
    @coordinates = Geocoder.coordinates(address)
    address      = Geocoder.address(@coordinates)
    trim_street_number(address)
  end

  # If a street number is a range reduce it to one number.
  def trim_street_number(address)
    address    = address.split(' ')
    address[0] = address[0].split('-').shift
    address.join(' ')
  end

  # Parses a String address and prepares for an HTTP request. Accepts Strings and Integers as args.
  def parse_address(address)
    address = convert_int_address_to_string(address)
    if address.is_a?(String)
      address.tr(',', '').split.join('%20')
    else
      address_type_error
    end
  end

  # Geocode an address and returns the coordinates.
  def get_coordinates(address)
    address = convert_int_address_to_string(address)
    if address.is_a?(String)
      Geocoder.coordinates(address)
    else
      address_type_error
    end
  end

  # Converts an integer to a string in case a zip was input as an int.
  def convert_int_address_to_string(address)
    if address.is_a?(Integer)
      format('0%o', address)
    else
      address
    end
  end

  # Creates an empty delegation if no reps were found.
  def handle_reps_not_found_error
    reps_not_found_error
    puts response
    Delegation.new
  end
end
