# frozen_string_literal: true
module GetYourRep
  # Office information. Belongs to Representative.
  class OfficeLocation
    include GetYourRep::Errors
    include GetYourRep::Associations

    # Each instance belongs to a Represenative, which has many OfficeLocations.
    attr_accessor :rep
    # Defines the type of office ('district' or 'capitol')
    attr_accessor :type
    # Line 1 of address.
    attr_accessor :line_1
    # Line 2 of address.
    attr_accessor :line_2
    # City, state and zip.
    attr_accessor :city, :state, :zip
    # Office phone
    attr_accessor :phone

    # Construct a new instance, setting attributes from an options hash.
    def initialize(office_hash = {})
      office_hash.each do |key, val|
        send("#{key}=", val)
      end
    end

    # Display self attributes for CLI.
    def cli_display
      puts "  #{type.capitalize} Office".bold.blue
      office_lines = [line_1, line_2, "#{city}, #{state} #{zip}"]
      office_lines.each { |line| puts "    #{line}".red if line }
    end
  end
end
